summaryrefslogtreecommitdiffstats
path: root/konsole/konsole
diff options
context:
space:
mode:
Diffstat (limited to 'konsole/konsole')
-rw-r--r--konsole/konsole/TEHistory.cpp6
-rw-r--r--konsole/konsole/TEPty.cpp2
-rw-r--r--konsole/konsole/TEScreen.cpp12
-rw-r--r--konsole/konsole/TEWidget.cpp102
-rw-r--r--konsole/konsole/TEWidget.h2
-rw-r--r--konsole/konsole/TEmuVt102.cpp48
-rw-r--r--konsole/konsole/TEmuVt102.h2
-rw-r--r--konsole/konsole/TEmulation.cpp8
-rw-r--r--konsole/konsole/fontembedder.cpp12
-rw-r--r--konsole/konsole/keytrans.cpp34
-rw-r--r--konsole/konsole/keytrans.h8
-rw-r--r--konsole/konsole/konsole.cpp58
-rw-r--r--konsole/konsole/konsole_part.cpp52
-rw-r--r--konsole/konsole/konsole_part.h6
-rw-r--r--konsole/konsole/konsole_wcwidth.cpp12
-rw-r--r--konsole/konsole/konsole_wcwidth.h4
-rw-r--r--konsole/konsole/konsolebookmarkmenu.cpp4
-rw-r--r--konsole/konsole/linefont.h2
-rw-r--r--konsole/konsole/main.cpp6
-rw-r--r--konsole/konsole/schema.cpp18
-rw-r--r--konsole/konsole/schema.h6
-rw-r--r--konsole/konsole/session.cpp14
-rw-r--r--konsole/konsole/session.h2
23 files changed, 210 insertions, 210 deletions
diff --git a/konsole/konsole/TEHistory.cpp b/konsole/konsole/TEHistory.cpp
index cbe8b199d..172887c9c 100644
--- a/konsole/konsole/TEHistory.cpp
+++ b/konsole/konsole/TEHistory.cpp
@@ -62,7 +62,7 @@ FIXME: There is noticeable decrease in speed, also. Perhaps,
scheme with wrap around would be it's complexity.
*/
-//FIXME: tempory replacement for tmpfile
+//FIXME: tempory tqreplacement for tmpfile
// this is here one for debugging purpose.
//#define tmpfile xTmpFile
@@ -135,7 +135,7 @@ bool HistoryScroll::hasScroll()
/*
The history scroll makes a Row(Row(Cell)) from
- two history buffers. The index buffer contains
+ two history buffers. The index buffer tqcontains
start of line positions which refere to the cells
buffer.
@@ -457,7 +457,7 @@ void HistoryScrollBlockArray::addCells(ca a[], int count)
size_t *pLen = new size_t;
*pLen = count;
- m_lineLengths.replace(m_blockArray.getCurrent(), pLen);
+ m_lineLengths.tqreplace(m_blockArray.getCurrent(), pLen);
}
void HistoryScrollBlockArray::addLine(bool)
diff --git a/konsole/konsole/TEPty.cpp b/konsole/konsole/TEPty.cpp
index 86e916e57..76aeaaa7d 100644
--- a/konsole/konsole/TEPty.cpp
+++ b/konsole/konsole/TEPty.cpp
@@ -44,7 +44,7 @@
\par FIXME
- [NOTE: much of the technical stuff below will be replaced by forkpty.]
+ [NOTE: much of the technical stuff below will be tqreplaced by forkpty.]
publish the SIGCHLD signal if not related to an instance.
diff --git a/konsole/konsole/TEScreen.cpp b/konsole/konsole/TEScreen.cpp
index 54b479844..1428ac90b 100644
--- a/konsole/konsole/TEScreen.cpp
+++ b/konsole/konsole/TEScreen.cpp
@@ -783,7 +783,7 @@ void TEScreen::compose(TQString compose)
TQChar c(image[lastPos].c);
compose.prepend(c);
compose.compose();
- image[lastPos].c = compose[0].unicode();
+ image[lastPos].c = compose[0].tqunicode();
}
// Region commands -------------------------------------------------------------
@@ -1023,7 +1023,7 @@ void TEScreen::clearEntireScreen()
}
/*! fill screen with 'E'
- This is to aid screen alignment
+ This is to aid screen tqalignment
*/
void TEScreen::helpAlign()
@@ -1281,7 +1281,7 @@ void TEScreen::getSelText(bool preserve_line_breaks, TQTextStream *stream)
while (hX < eol && hX <= sel_Right % columns)
{
- Q_UINT16 c = hist->getCell(hY, hX++).c;
+ TQ_UINT16 c = hist->getCell(hY, hX++).c;
if (c)
m[d++] = c;
s++;
@@ -1293,7 +1293,7 @@ void TEScreen::getSelText(bool preserve_line_breaks, TQTextStream *stream)
}
else { // or from screen image.
if (testIsSelected((s - hist_BR) % columns, (s - hist_BR) / columns)) {
- Q_UINT16 c = image[s++ - hist_BR].c;
+ TQ_UINT16 c = image[s++ - hist_BR].c;
if (c) {
m[d++] = c;
newlineneeded = true;
@@ -1334,7 +1334,7 @@ void TEScreen::getSelText(bool preserve_line_breaks, TQTextStream *stream)
while (hX < eol)
{
- Q_UINT16 c = hist->getCell(hY, hX++).c;
+ TQ_UINT16 c = hist->getCell(hY, hX++).c;
if (c)
m[d++] = c;
s++;
@@ -1401,7 +1401,7 @@ void TEScreen::getSelText(bool preserve_line_breaks, TQTextStream *stream)
while (s <= eol)
{
- Q_UINT16 c = image[s++ - hist_BR].c;
+ TQ_UINT16 c = image[s++ - hist_BR].c;
if (c)
m[d++] = c;
}
diff --git a/konsole/konsole/TEWidget.h b/konsole/konsole/TEWidget.h
index 2c11eac2e..ae7e0a8ec 100644
--- a/konsole/konsole/TEWidget.h
+++ b/konsole/konsole/TEWidget.h
@@ -96,7 +96,7 @@ public:
void updateImageSize();
void setSize(int cols, int lins);
void setFixedSize(int cols, int lins);
- TQSize sizeHint() const;
+ TQSize tqsizeHint() const;
void setWordCharacters(TQString wc);
TQString wordCharacters() { return word_characters; }
diff --git a/konsole/konsole/TEmuVt102.cpp b/konsole/konsole/TEmuVt102.cpp
index 0bdb0f42c..a60246106 100644
--- a/konsole/konsole/TEmuVt102.cpp
+++ b/konsole/konsole/TEmuVt102.cpp
@@ -307,7 +307,7 @@ void TEmuVt102::initTokenizer()
#define ESC 27
#define CNTL(c) ((c)-'@')
-// process an incoming unicode character
+// process an incoming tqunicode character
void TEmuVt102::onRcvChar(int cc)
{ int i;
@@ -606,7 +606,7 @@ switch( N )
case TY_CSI_PS('m', 106) : scr->setBackColor (CO_SYS, 14); break;
case TY_CSI_PS('m', 107) : scr->setBackColor (CO_SYS, 15); break;
- case TY_CSI_PS('n', 5) : reportStatus ( ); break;
+ case TY_CSI_PS('n', 5) : reporttqStatus ( ); break;
case TY_CSI_PS('n', 6) : reportCursorPosition ( ); break;
case TY_CSI_PS('q', 0) : /* IGNORED: LEDs off */ break; //VT100
case TY_CSI_PS('q', 1) : /* IGNORED: LED1 on */ break; //VT100
@@ -847,7 +847,7 @@ void TEmuVt102::reportTerminalParms(int p)
/*!
*/
-void TEmuVt102::reportStatus()
+void TEmuVt102::reporttqStatus()
{
sendString("\033[0n"); //VT100. Device status report. 0 = Ready.
}
@@ -1007,7 +1007,7 @@ void TEmuVt102::onKeyPress( TQKeyEvent* ev )
// Character Set Conversion ------------------------------------------------ --
/*
- The processing contains a VT100 specific code translation layer.
+ The processing tqcontains a VT100 specific code translation layer.
It's still in use and mainly responsible for the line drawing graphics.
These and some other glyphs are assigned to codes (0x5f-0xfe)
@@ -1328,7 +1328,7 @@ static int xkb_init()
#if 0
// This method doesn't work in all cases. The atom "ScrollLock" doesn't seem
// to exist on all XFree versions (at least it's not here with my 3.3.6) - DF
-static unsigned int xkb_mask_modifier( XkbDescPtr xkb, const char *name )
+static unsigned int xkb_tqmask_modifier( XkbDescPtr xkb, const char *name )
{
int i;
if( !xkb || !xkb->names )
@@ -1344,30 +1344,30 @@ static unsigned int xkb_mask_modifier( XkbDescPtr xkb, const char *name )
{
if (atom == xkb->names->vmods[i] )
{
- unsigned int mask;
- XkbVirtualModsToReal( xkb, 1 << i, &mask );
- return mask;
+ unsigned int tqmask;
+ XkbVirtualModsToReal( xkb, 1 << i, &tqmask );
+ return tqmask;
}
}
return 0;
}
-static unsigned int xkb_scrolllock_mask()
+static unsigned int xkb_scrolllock_tqmask()
{
XkbDescPtr xkb;
if(( xkb = XkbGetKeyboard( qt_xdisplay(), XkbAllComponentsMask, XkbUseCoreKbd )) != NULL )
{
- unsigned int mask = xkb_mask_modifier( xkb, "ScrollLock" );
+ unsigned int tqmask = xkb_tqmask_modifier( xkb, "ScrollLock" );
XkbFreeKeyboard( xkb, 0, True );
- return mask;
+ return tqmask;
}
return 0;
}
#else
-static unsigned int xkb_scrolllock_mask()
+static unsigned int xkb_scrolllock_tqmask()
{
- int scrolllock_mask = 0;
+ int scrolllock_tqmask = 0;
XModifierKeymap* map = XGetModifierMapping( qt_xdisplay() );
KeyCode scrolllock_keycode = XKeysymToKeycode( qt_xdisplay(), XK_Scroll_Lock );
if( scrolllock_keycode == NoSymbol ) {
@@ -1379,42 +1379,42 @@ static unsigned int xkb_scrolllock_mask()
++i )
{
if( map->modifiermap[ map->max_keypermod * i ] == scrolllock_keycode )
- scrolllock_mask += 1 << i;
+ scrolllock_tqmask += 1 << i;
}
XFreeModifiermap(map);
- return scrolllock_mask;
+ return scrolllock_tqmask;
}
#endif
-static unsigned int scrolllock_mask = 0;
+static unsigned int scrolllock_tqmask = 0;
static int xkb_set_on()
{
- if (!scrolllock_mask)
+ if (!scrolllock_tqmask)
{
if( !xkb_init())
return 0;
- scrolllock_mask = xkb_scrolllock_mask();
- if( scrolllock_mask == 0 )
+ scrolllock_tqmask = xkb_scrolllock_tqmask();
+ if( scrolllock_tqmask == 0 )
return 0;
}
- XkbLockModifiers ( qt_xdisplay(), XkbUseCoreKbd, scrolllock_mask, scrolllock_mask);
+ XkbLockModifiers ( qt_xdisplay(), XkbUseCoreKbd, scrolllock_tqmask, scrolllock_tqmask);
return 1;
}
static int xkb_set_off()
{
- if (!scrolllock_mask)
+ if (!scrolllock_tqmask)
{
if( !xkb_init())
return 0;
- scrolllock_mask = xkb_scrolllock_mask();
- if( scrolllock_mask == 0 )
+ scrolllock_tqmask = xkb_scrolllock_tqmask();
+ if( scrolllock_tqmask == 0 )
return 0;
}
- XkbLockModifiers ( qt_xdisplay(), XkbUseCoreKbd, scrolllock_mask, 0);
+ XkbLockModifiers ( qt_xdisplay(), XkbUseCoreKbd, scrolllock_tqmask, 0);
return 1;
}
diff --git a/konsole/konsole/TEmuVt102.h b/konsole/konsole/TEmuVt102.h
index 05f30ac04..fde0f9557 100644
--- a/konsole/konsole/TEmuVt102.h
+++ b/konsole/konsole/TEmuVt102.h
@@ -117,7 +117,7 @@ private:
void reportTerminalType();
void reportSecondaryAttributes();
- void reportStatus();
+ void reporttqStatus();
void reportAnswerBack();
void reportCursorPosition();
void reportTerminalParms(int p);
diff --git a/konsole/konsole/fontembedder.cpp b/konsole/konsole/fontembedder.cpp
index dfbd88ce4..d0c17e084 100644
--- a/konsole/konsole/fontembedder.cpp
+++ b/konsole/konsole/fontembedder.cpp
@@ -26,7 +26,7 @@
using namespace std;
-static Q_UINT32 charVal(TQChar val)
+static TQ_UINT32 charVal(TQChar val)
{
if (val == ' ')
return 0;
@@ -34,13 +34,13 @@ static Q_UINT32 charVal(TQChar val)
return 1;
}
-static Q_UINT32 readGlyphLine(TQTextStream& input)
+static TQ_UINT32 readGlyphLine(TQTextStream& input)
{
TQString line = input.readLine();
while (line.length() < 5)
line += ' ';
- Q_UINT32 val = charVal(line[0]) |
+ TQ_UINT32 val = charVal(line[0]) |
(charVal(line[1]) << 1) |
(charVal(line[2]) << 2) |
(charVal(line[3]) << 3) |
@@ -48,7 +48,7 @@ static Q_UINT32 readGlyphLine(TQTextStream& input)
return val;
}
-static Q_UINT32 readGlyph(TQTextStream& input)
+static TQ_UINT32 readGlyph(TQTextStream& input)
{
return readGlyphLine(input) |
(readGlyphLine(input) << 5) |
@@ -72,7 +72,7 @@ int main(int argc, char **argv)
TQTextStream input(&inFile);
- Q_UINT32 glyphStates[128];
+ TQ_UINT32 glyphStates[128];
for (int i = 0; i < 128; ++i)
glyphStates[i] = 0; //nothing..
@@ -98,7 +98,7 @@ int main(int argc, char **argv)
//Output.
cout<<"// WARNING: Autogenerated by \"fontembedder " << argv[1] << "\".\n";
cout<<"// You probably do not want to hand-edit this!\n\n";
- cout<<"static const Q_UINT32 LineChars[] = {\n";
+ cout<<"static const TQ_UINT32 LineChars[] = {\n";
//Nicely formatted: 8 per line, 16 lines
for (int line = 0; line < 128; line += 8)
diff --git a/konsole/konsole/keytrans.cpp b/konsole/konsole/keytrans.cpp
index 36e299bc0..af97b0a85 100644
--- a/konsole/konsole/keytrans.cpp
+++ b/konsole/konsole/keytrans.cpp
@@ -41,8 +41,8 @@
instances represent the individual assignments
*/
-KeyTrans::KeyEntry::KeyEntry(int _ref, int _key, int _bits, int _mask, int _cmd, TQString _txt)
-: ref(_ref), key(_key), bits(_bits), mask(_mask), cmd(_cmd), txt(_txt)
+KeyTrans::KeyEntry::KeyEntry(int _ref, int _key, int _bits, int _tqmask, int _cmd, TQString _txt)
+: ref(_ref), key(_key), bits(_bits), tqmask(_tqmask), cmd(_cmd), txt(_txt)
{
}
@@ -50,20 +50,20 @@ KeyTrans::KeyEntry::~KeyEntry()
{
}
-bool KeyTrans::KeyEntry::matches(int _key, int _bits, int _mask)
-{ int m = mask & _mask;
+bool KeyTrans::KeyEntry::matches(int _key, int _bits, int _tqmask)
+{ int m = tqmask & _tqmask;
return _key == key && (bits & m) == (_bits & m);
}
bool KeyTrans::KeyEntry::metaspecified(void)
{
- return ((mask & (1 << BITS_Alt)) && (bits & (1 << BITS_Alt))) ||
- ((mask & (1 << BITS_AnyMod)) && (bits & (1 << BITS_AnyMod)));
+ return ((tqmask & (1 << BITS_Alt)) && (bits & (1 << BITS_Alt))) ||
+ ((tqmask & (1 << BITS_AnyMod)) && (bits & (1 << BITS_AnyMod)));
}
bool KeyTrans::KeyEntry::anymodspecified(void)
{
- return (mask & (1 << BITS_AnyMod)) && (bits & (1 << BITS_AnyMod));
+ return (tqmask & (1 << BITS_AnyMod)) && (bits & (1 << BITS_AnyMod));
}
TQString KeyTrans::KeyEntry::text()
@@ -110,17 +110,17 @@ KeyTrans::~KeyTrans()
{
}
-KeyTrans::KeyEntry* KeyTrans::addEntry(int ref, int key, int bits, int mask, int cmd, TQString txt)
+KeyTrans::KeyEntry* KeyTrans::addEntry(int ref, int key, int bits, int tqmask, int cmd, TQString txt)
// returns conflicting entry
{
for (TQPtrListIterator<KeyEntry> it(tableX); it.current(); ++it)
{
- if (it.current()->matches(key,bits,mask))
+ if (it.current()->matches(key,bits,tqmask))
{
return it.current();
}
}
- tableX.append(new KeyEntry(ref,key,bits,mask,cmd,txt));
+ tableX.append(new KeyEntry(ref,key,bits,tqmask,cmd,txt));
return (KeyEntry*)NULL;
}
@@ -141,10 +141,10 @@ bool KeyTrans::findEntry(int key, int bits, int* cmd, const char** txt, int* len
{
static char buf[16];
char *c;
- char mask = '1' + BITS(0, bits&(1<<BITS_Shift)) + BITS(1, bits&(1<<BITS_Alt)) + BITS(2, bits&(1<<BITS_Control));
+ char tqmask = '1' + BITS(0, bits&(1<<BITS_Shift)) + BITS(1, bits&(1<<BITS_Alt)) + BITS(2, bits&(1<<BITS_Control));
strcpy(buf, it.current()->txt.ascii());
c = (char*)strchr(buf, '*');
- if (c) *c = mask;
+ if (c) *c = tqmask;
*txt = buf;
}
else
@@ -402,7 +402,7 @@ Loop:
//printf(" key %s (%04x)",res.latin1(),(int)syms->keysyms[res]-1);
getSymbol(); // + - :
int mode = 0;
- int mask = 0;
+ int tqmask = 0;
while (sym == SYMOpr && (!strcmp(res.latin1(),"+") || !strcmp(res.latin1(),"-")))
{
bool on = !strcmp(res.latin1(),"+");
@@ -411,14 +411,14 @@ Loop:
assertSyntax(sym == SYMName, "Name expected")
assertSyntax(syms->modsyms[res], "Unknown mode name")
ptrdiff_t bits = (ptrdiff_t)(syms->modsyms[res]) - 1;
- if (mask & (1 << bits))
+ if (tqmask & (1 << bits))
{
fprintf(stderr,"%s(%d,%d): mode name used multiple times.\n",path.ascii(),slinno,scolno);
}
else
{
mode |= (on << bits);
- mask |= (1 << bits);
+ tqmask |= (1 << bits);
}
//printf(", mode %s(%d) %s",res.latin1(),(int)syms->modsyms[res]-1,on?"on":"off");
getSymbol();
@@ -441,8 +441,8 @@ Loop:
//for (unsigned i = 0; i < res.length(); i++)
//printf(" %02x(%c)",res.latin1()[i],res.latin1()[i]>=' '?res.latin1()[i]:'?');
}
-//printf(". summary %04x,%02x,%02x,%d\n",key,mode,mask,cmd);
- KeyTrans::KeyEntry* ke = kt->addEntry(slinno,key,mode,mask,cmd,res);
+//printf(". summary %04x,%02x,%02x,%d\n",key,mode,tqmask,cmd);
+ KeyTrans::KeyEntry* ke = kt->addEntry(slinno,key,mode,tqmask,cmd,res);
if (ke)
{
fprintf(stderr,"%s(%d): keystroke already assigned in line %d.\n",path.ascii(),slinno,ke->ref);
diff --git a/konsole/konsole/keytrans.h b/konsole/konsole/keytrans.h
index 2ddf5f776..c5268c4fd 100644
--- a/konsole/konsole/keytrans.h
+++ b/konsole/konsole/keytrans.h
@@ -68,9 +68,9 @@ class KeyTrans
class KeyEntry
{
public:
- KeyEntry(int ref, int key, int bits, int mask, int cmd, TQString txt);
+ KeyEntry(int ref, int key, int bits, int tqmask, int cmd, TQString txt);
~KeyEntry();
- bool matches(int key, int bits, int mask);
+ bool matches(int key, int bits, int tqmask);
bool metaspecified(void);
bool anymodspecified(void);
TQString text();
@@ -78,14 +78,14 @@ class KeyTrans
private:
int key;
int bits;
- int mask;
+ int tqmask;
public:
int cmd;
TQString txt;
};
private:
- KeyEntry* addEntry(int ref, int key, int bits, int mask, int cmd, TQString txt);
+ KeyEntry* addEntry(int ref, int key, int bits, int tqmask, int cmd, TQString txt);
void addKeyTrans();
void readConfig();
TQPtrList<KeyEntry> tableX;
diff --git a/konsole/konsole/konsole.cpp b/konsole/konsole/konsole.cpp
index ecef79d4a..5badd652d 100644
--- a/konsole/konsole/konsole.cpp
+++ b/konsole/konsole/konsole.cpp
@@ -789,7 +789,7 @@ void Konsole::makeGUI()
KeyTrans* ktr = kt_map[*it];
assert( ktr );
TQString title=ktr->hdr();
- m_keytab->insertItem(title.replace('&',"&&"),ktr->numb());
+ m_keytab->insertItem(title.tqreplace('&',"&&"),ktr->numb());
}
applySettingsToGUI();
@@ -1280,7 +1280,7 @@ void Konsole::setColLin(int columns, int lines)
te->setSize(columns, lines);
adjustSize();
if (b_fixedSize)
- setFixedSize(sizeHint());
+ setFixedSize(tqsizeHint());
notifySize(columns, lines); // set menu items
}
}
@@ -1316,7 +1316,7 @@ void Konsole::slotTabContextMenu(TQWidget* _te, const TQPoint & pos)
int counter=0;
for (TESession *ses = sessions.first(); ses; ses = sessions.next()) {
TQString title=ses->Title();
- m_tabPopupTabsMenu->insertItem(SmallIcon(ses->IconName()),title.replace('&',"&&"),counter++);
+ m_tabPopupTabsMenu->insertItem(SmallIcon(ses->IconName()),title.tqreplace('&',"&&"),counter++);
}
m_tabPopupMenu->popup( pos );
@@ -1382,7 +1382,7 @@ void Konsole::slotTabSetViewOptions(int mode)
else
title = sessions.at(i)->Title();
- title=title.replace('&',"&&");
+ title=title.tqreplace('&',"&&");
switch(mode) {
case ShowIconAndText:
tabwidget->changeTab(page, icon, title);
@@ -1428,7 +1428,7 @@ void Konsole::slotSaveSessionsProfile()
TQString::null, &ok, this );
if ( ok ) {
TQString path = locateLocal( "data",
- TQString::fromLatin1( "konsole/profiles/" ) + prof,
+ TQString::tqfromLatin1( "konsole/profiles/" ) + prof,
KGlobal::instance() );
if ( TQFile::exists( path ) )
@@ -1635,7 +1635,7 @@ void Konsole::readProperties(KConfig* config, const TQString &schema, bool globa
delete rootxpms[te];
rootxpms.remove(te);
}
- pixmap_menu_activated(sch->alignment());
+ pixmap_menu_activated(sch->tqalignment());
}
te->setColorTable(sch->table()); //FIXME: set twice here to work around a bug
@@ -1874,7 +1874,7 @@ void Konsole::updateSchemaMenu()
ColorSchema* s = (ColorSchema*)colors->at(i);
assert( s );
TQString title=s->title();
- m_schema->insertItem(title.replace('&',"&&"),s->numb(),0);
+ m_schema->insertItem(title.tqreplace('&',"&&"),s->numb(),0);
}
if (te && se)
@@ -1912,7 +1912,7 @@ void Konsole::slotToggleMenubar() {
if (b_fixedSize)
{
adjustSize();
- setFixedSize(sizeHint());
+ setFixedSize(tqsizeHint());
}
if (!showMenubar->isChecked()) {
setCaption(i18n("Use the right mouse button to bring back the menu"));
@@ -1987,12 +1987,12 @@ void Konsole::slotSelectTabbar() {
/* FIXME: Still necessary ? */
TQPtrDictIterator<KRootPixmap> it(rootxpms);
for (;it.current();++it)
- it.current()->repaint(true);
+ it.current()->tqrepaint(true);
if (b_fixedSize)
{
adjustSize();
- setFixedSize(sizeHint());
+ setFixedSize(tqsizeHint());
}
}
@@ -2224,7 +2224,7 @@ void Konsole::updateTitle(TESession* _se)
if (m_tabViewMode == ShowIconOnly)
tabwidget->changeTab( _se->widget(), TQString::null );
else if (b_matchTabWinTitle)
- tabwidget->setTabLabel( _se->widget(), _se->fullTitle().replace('&',"&&"));
+ tabwidget->setTabLabel( _se->widget(), _se->fullTitle().tqreplace('&',"&&"));
}
void Konsole::initSessionFont(TQFont font) {
@@ -2362,7 +2362,7 @@ void Konsole::enterURL(const TQString& URL, const TQString&)
KRun::shellQuote(newtext);
te->emitText("cd "+newtext+"\r");
}
- else if (URL.contains("://", true)) {
+ else if (URL.tqcontains("://", true)) {
KURL u(URL);
newtext = u.protocol();
bool isSSH = (newtext == "ssh");
@@ -2445,7 +2445,7 @@ void Konsole::addSession(TESession* s)
s->setTitle(newTitle);
// create an action for the session
- KRadioAction *ra = new KRadioAction(newTitle.replace('&',"&&"),
+ KRadioAction *ra = new KRadioAction(newTitle.tqreplace('&',"&&"),
s->IconName(),
0,
this,
@@ -2496,7 +2496,7 @@ void Konsole::listSessions()
m_sessionList->setKeyboardShortcutsEnabled(true);
for (TESession *ses = sessions.first(); ses; ses = sessions.next()) {
TQString title=ses->Title();
- m_sessionList->insertItem(SmallIcon(ses->IconName()),title.replace('&',"&&"),counter++);
+ m_sessionList->insertItem(SmallIcon(ses->IconName()),title.tqreplace('&',"&&"),counter++);
}
m_sessionList->adjustSize();
m_sessionList->popup(mapToGlobal(TQPoint((width()/2)-(m_sessionList->width()/2),(height()/2)-(m_sessionList->height()/2))));
@@ -2575,7 +2575,7 @@ void Konsole::activateSession(TESession *s)
s_schema = cs->relPath();
curr_schema = cs->numb();
pmPath = cs->imagePath();
- n_render = cs->alignment();
+ n_render = cs->tqalignment();
// BR 106464 temporary fix...
// only 2 sessions opened, 2nd session viewable, right-click on 1st tab and
@@ -3138,7 +3138,7 @@ void Konsole::moveSessionLeft()
tabwidget->blockSignals(false);
TQString title = se->Title();
createSessionTab(se->widget(), iconSetForSession(se),
- title.replace('&', "&&"), position-1);
+ title.tqreplace('&', "&&"), position-1);
tabwidget->showPage(se->widget());
tabwidget->setTabColor(se->widget(),oldcolor);
@@ -3171,7 +3171,7 @@ void Konsole::moveSessionRight()
tabwidget->blockSignals(false);
TQString title = se->Title();
createSessionTab(se->widget(), iconSetForSession(se),
- title.replace('&', "&&"), position+1);
+ title.tqreplace('&', "&&"), position+1);
tabwidget->showPage(se->widget());
tabwidget->setTabColor(se->widget(),oldcolor);
@@ -3383,7 +3383,7 @@ void Konsole::addSessionCommand(const TQString &path)
TQString name = comment;
name.prepend("SSC_"); // Allows easy searching for Session ShortCuts
- name.replace(" ", "_");
+ name.tqreplace(" ", "_");
sl_sessionShortCuts << name;
// Is there already this shortcut?
@@ -3433,13 +3433,13 @@ void Konsole::createSessionMenus()
TQString txt = cfg->readEntry("Name");
TQString icon = cfg->readEntry("Icon", "konsole");
insertItemSorted(m_tabbarSessionsCommands, SmallIconSet(icon),
- txt.replace('&',"&&"), SESSION_NEW_SHELL_ID );
+ txt.tqreplace('&',"&&"), SESSION_NEW_SHELL_ID );
TQString comment = cfg->readEntry("Comment");
if (comment.isEmpty())
comment=txt.prepend(i18n("New "));
insertItemSorted(m_session, SmallIconSet(icon),
- comment.replace('&',"&&"), SESSION_NEW_SHELL_ID);
+ comment.tqreplace('&',"&&"), SESSION_NEW_SHELL_ID);
m_session->insertItem(SmallIconSet("window_new"),
i18n("New &Window"), SESSION_NEW_WINDOW_ID);
m_tabbarSessionsCommands->insertItem(SmallIconSet("window_new"),
@@ -3455,12 +3455,12 @@ void Konsole::createSessionMenus()
TQString txt = (*it).readEntry("Name");
TQString icon = (*it).readEntry("Icon", "konsole");
insertItemSorted(m_tabbarSessionsCommands, SmallIconSet(icon),
- txt.replace('&',"&&"), it.currentKey() );
+ txt.tqreplace('&',"&&"), it.currentKey() );
TQString comment = (*it).readEntry("Comment");
if (comment.isEmpty())
comment=txt.prepend(i18n("New "));
insertItemSorted(m_session, SmallIconSet(icon),
- comment.replace('&',"&&"), it.currentKey());
+ comment.tqreplace('&',"&&"), it.currentKey());
}
if (m_bookmarksSession)
@@ -3483,7 +3483,7 @@ void Konsole::addScreenSession(const TQString &path, const TQString &socket)
co->writeEntry("Name", socket);
TQString txt = i18n("Screen is a program controlling screens!", "Screen at %1").arg(socket);
co->writeEntry("Comment", txt);
- co->writePathEntry("Exec", TQString::fromLatin1("SCREENDIR=%1 screen -r %2")
+ co->writePathEntry("Exec", TQString::tqfromLatin1("SCREENDIR=%1 screen -r %2")
.arg(path).arg(socket));
TQString icon = "konsole";
cmd_serial++;
@@ -3616,7 +3616,7 @@ void Konsole::setSchema(ColorSchema* s, TEWidget* tewidget)
rootxpms.insert( tewidget, new KRootPixmap(tewidget) );
rootxpms[tewidget]->setFadeEffect(s->tr_x(), TQColor(s->tr_r(), s->tr_g(), s->tr_b()));
} else {
- tewidget->setBlendColor(qRgba(s->tr_r(), s->tr_g(), s->tr_b(), int(s->tr_x() * 255)));
+ tewidget->setBlendColor(tqRgba(s->tr_r(), s->tr_g(), s->tr_b(), int(s->tr_x() * 255)));
tewidget->setErasePixmap( TQPixmap() ); // make sure any background pixmap is unset
}
} else {
@@ -3624,8 +3624,8 @@ void Konsole::setSchema(ColorSchema* s, TEWidget* tewidget)
delete rootxpms[tewidget];
rootxpms.remove(tewidget);
}
- pixmap_menu_activated(s->alignment(), tewidget);
- tewidget->setBlendColor(qRgba(0, 0, 0, 0xff));
+ pixmap_menu_activated(s->tqalignment(), tewidget);
+ tewidget->setBlendColor(tqRgba(0, 0, 0, 0xff));
}
tewidget->setColorTable(s->table());
@@ -3749,7 +3749,7 @@ void Konsole::attachSession(TESession* session)
}
TQString title=session->Title();
- KRadioAction *ra = new KRadioAction(title.replace('&',"&&"), session->IconName(),
+ KRadioAction *ra = new KRadioAction(title.tqreplace('&',"&&"), session->IconName(),
0, this, TQT_SLOT(activateSession()), m_shortcuts);
ra->setExclusiveGroup("sessions");
@@ -3811,7 +3811,7 @@ void Konsole::slotRenameSession(TESession* ses, const TQString &name)
{
KRadioAction *ra = session2action.find(ses);
TQString title=name;
- title=title.replace('&',"&&");
+ title=title.tqreplace('&',"&&");
ra->setText(title);
ra->setIcon( ses->IconName() ); // I don't know why it is needed here
if (m_tabViewMode!=ShowIconOnly)
@@ -4192,7 +4192,7 @@ void Konsole::toggleBidi()
TQPtrList<TEWidget> tes = activeTEs();
for (TEWidget *_te = tes.first(); _te; _te = tes.next()) {
_te->setBidiEnabled(b_bidiEnabled);
- _te->repaint();
+ _te->tqrepaint();
}
}
diff --git a/konsole/konsole/konsole_part.cpp b/konsole/konsole/konsole_part.cpp
index 620a0ebdb..b251007d1 100644
--- a/konsole/konsole/konsole_part.cpp
+++ b/konsole/konsole/konsole_part.cpp
@@ -76,12 +76,12 @@ konsoleFactory::~konsoleFactory()
s_aboutData = 0;
}
-KParts::Part *konsoleFactory::createPartObject(TQWidget *parentWidget, const char *widgetName,
+KParts::Part *konsoleFactory::createPartObject(TQWidget *tqparentWidget, const char *widgetName,
TQObject *parent, const char *name, const char *classname,
const TQStringList&)
{
-// kdDebug(1211) << "konsoleFactory::createPart parentWidget=" << parentWidget << " parent=" << parent << endl;
- KParts::Part *obj = new konsolePart(parentWidget, widgetName, parent, name, classname);
+// kdDebug(1211) << "konsoleFactory::createPart tqparentWidget=" << tqparentWidget << " parent=" << parent << endl;
+ KParts::Part *obj = new konsolePart(tqparentWidget, widgetName, parent, name, classname);
return obj;
}
@@ -97,7 +97,7 @@ KInstance *konsoleFactory::instance()
#define DEFAULT_HISTORY_SIZE 1000
-konsolePart::konsolePart(TQWidget *_parentWidget, const char *widgetName, TQObject *parent, const char *name, const char *classname)
+konsolePart::konsolePart(TQWidget *_tqparentWidget, const char *widgetName, TQObject *parent, const char *name, const char *classname)
: KParts::ReadOnlyPart(parent, name)
,te(0)
,se(0)
@@ -120,7 +120,7 @@ konsolePart::konsolePart(TQWidget *_parentWidget, const char *widgetName, TQObje
,m_histSize(DEFAULT_HISTORY_SIZE)
,m_runningShell( false )
{
- parentWidget=_parentWidget;
+ tqparentWidget=_tqparentWidget;
setInstance(konsoleFactory::instance());
m_extension = new konsoleBrowserExtension(this);
@@ -137,7 +137,7 @@ konsolePart::konsolePart(TQWidget *_parentWidget, const char *widgetName, TQObje
const char* shell = getenv("SHELL");
if (shell == NULL || *shell == '\0') shell = "/bin/sh";
eargs.append(shell);
- te = new TEWidget(parentWidget,widgetName);
+ te = new TEWidget(tqparentWidget,widgetName);
te->setMinimumSize(150,70); // allow resizing, cause resize in TEWidget
setWidget(te);
@@ -197,7 +197,7 @@ konsolePart::konsolePart(TQWidget *_parentWidget, const char *widgetName, TQObje
KeyTrans* ktr = kt_map[*it];
assert( ktr );
TQString title=ktr->hdr();
- m_keytab->insertItem(title.replace('&',"&&"),ktr->numb());
+ m_keytab->insertItem(title.tqreplace('&',"&&"),ktr->numb());
}
}
@@ -317,13 +317,13 @@ void konsolePart::makeGUI()
if (!kapp->authorizeKAction("konsole_rmb"))
return;
- actions = new KActionCollection( (KMainWindow*)parentWidget );
- settingsActions = new KActionCollection( (KMainWindow*)parentWidget );
+ actions = new KActionCollection( (KMainWindow*)tqparentWidget );
+ settingsActions = new KActionCollection( (KMainWindow*)tqparentWidget );
// Send Signal Menu -------------------------------------------------------------
if (kapp->authorizeKAction("send_signal"))
{
- m_signals = new KPopupMenu((KMainWindow*)parentWidget);
+ m_signals = new KPopupMenu((KMainWindow*)tqparentWidget);
m_signals->insertItem( i18n( "&Suspend Task" ) + " (STOP)", SIGSTOP);
m_signals->insertItem( i18n( "&Continue Task" ) + " (CONT)", SIGCONT);
m_signals->insertItem( i18n( "&Hangup" ) + " (HUP)", SIGHUP);
@@ -338,7 +338,7 @@ void konsolePart::makeGUI()
// Settings Menu ----------------------------------------------------------------
if (kapp->authorizeKAction("settings"))
{
- m_options = new KPopupMenu((KMainWindow*)parentWidget);
+ m_options = new KPopupMenu((KMainWindow*)tqparentWidget);
// Scrollbar
selectScrollbar = new KSelectAction(i18n("Sc&rollbar"), 0, this,
@@ -379,7 +379,7 @@ void konsolePart::makeGUI()
// Keyboard Options Menu ---------------------------------------------------
if (kapp->authorizeKAction("keyboard"))
{
- m_keytab = new KPopupMenu((KMainWindow*)parentWidget);
+ m_keytab = new KPopupMenu((KMainWindow*)tqparentWidget);
m_keytab->setCheckable(true);
connect(m_keytab, TQT_SIGNAL(activated(int)), TQT_SLOT(keytab_menu_activated(int)));
m_options->insertItem( SmallIconSet( "key_bindings" ), i18n( "&Keyboard" ), m_keytab );
@@ -388,7 +388,7 @@ void konsolePart::makeGUI()
// Schema Options Menu -----------------------------------------------------
if (kapp->authorizeKAction("schema"))
{
- m_schema = new KPopupMenu((KMainWindow*)parentWidget);
+ m_schema = new KPopupMenu((KMainWindow*)tqparentWidget);
m_schema->setCheckable(true);
connect(m_schema, TQT_SIGNAL(activated(int)), TQT_SLOT(schema_menu_activated(int)));
connect(m_schema, TQT_SIGNAL(aboutToShow()), TQT_SLOT(schema_menu_check()));
@@ -452,7 +452,7 @@ void konsolePart::makeGUI()
}
// Popup Menu -------------------------------------------------------------------
- m_popupMenu = new KPopupMenu((KMainWindow*)parentWidget);
+ m_popupMenu = new KPopupMenu((KMainWindow*)tqparentWidget);
KAction* selectionEnd = new KAction(i18n("Set Selection End"), 0, te,
TQT_SLOT(setSelectionEnd()), actions, "selection_end");
selectionEnd->plug(m_popupMenu);
@@ -590,7 +590,7 @@ void konsolePart::readProperties()
rootxpm = new KRootPixmap(te);
rootxpm->setFadeEffect(sch->tr_x(), TQColor(sch->tr_r(), sch->tr_g(), sch->tr_b()));
rootxpm->start();
- rootxpm->repaint(true);
+ rootxpm->tqrepaint(true);
}
else {
if (rootxpm) {
@@ -598,7 +598,7 @@ void konsolePart::readProperties()
delete rootxpm;
rootxpm=0;
}
- pixmap_menu_activated(sch->alignment());
+ pixmap_menu_activated(sch->tqalignment());
}
te->setBellMode(n_bell);
@@ -733,7 +733,7 @@ void konsolePart::updateSchemaMenu()
for (int i = 0; i < (int) colors->count(); i++) {
ColorSchema* s = (ColorSchema*)colors->at(i);
TQString title=s->title();
- m_schema->insertItem(title.replace('&',"&&"),s->numb(),0);
+ m_schema->insertItem(title.tqreplace('&',"&&"),s->numb(),0);
}
if (te && se) {
@@ -778,7 +778,7 @@ void konsolePart::setSchema(ColorSchema* s)
rootxpm = new KRootPixmap(te);
rootxpm->setFadeEffect(s->tr_x(), TQColor(s->tr_r(), s->tr_g(), s->tr_b()));
rootxpm->start();
- rootxpm->repaint(true);
+ rootxpm->tqrepaint(true);
}
else {
if (rootxpm) {
@@ -786,7 +786,7 @@ void konsolePart::setSchema(ColorSchema* s)
delete rootxpm;
rootxpm=0;
}
- pixmap_menu_activated(s->alignment());
+ pixmap_menu_activated(s->tqalignment());
}
te->setColorTable(s->table());
@@ -797,8 +797,8 @@ void konsolePart::notifySize(int /* columns */, int /* lines */)
{
ColorSchema *sch=colors->find(s_schema);
- if (sch && sch->alignment() >= 3)
- pixmap_menu_activated(sch->alignment());
+ if (sch && sch->tqalignment() >= 3)
+ pixmap_menu_activated(sch->tqalignment());
}
void konsolePart::pixmap_menu_activated(int item)
@@ -847,7 +847,7 @@ void konsolePart::pixmap_menu_activated(int item)
void konsolePart::slotHistoryType()
{
if ( ! se ) return;
- HistoryTypeDialog dlg(se->history(), m_histSize, (KMainWindow*)parentWidget);
+ HistoryTypeDialog dlg(se->history(), m_histSize, (KMainWindow*)tqparentWidget);
if (dlg.exec()) {
if (dlg.isOn()) {
if (dlg.nbLines() > 0) {
@@ -917,7 +917,7 @@ void konsolePart::slotWordSeps() {
bool ok;
TQString seps = KInputDialog::getText( i18n( "Word Connectors" ),
- i18n( "Characters other than alphanumerics considered part of a word when double clicking:" ), s_word_seps, &ok, parentWidget );
+ i18n( "Characters other than alphanumerics considered part of a word when double clicking:" ), s_word_seps, &ok, tqparentWidget );
if ( ok )
{
s_word_seps = seps;
@@ -1077,7 +1077,7 @@ bool konsolePart::setPtyFd( int master_pty )
void konsolePart::newSession()
{
if ( se ) delete se;
- se = new TESession(te, "xterm", parentWidget->winId());
+ se = new TESession(te, "xterm", tqparentWidget->winId());
connect( se,TQT_SIGNAL(done(TESession*)),
this,TQT_SLOT(doneSession(TESession*)) );
connect( se,TQT_SIGNAL(openURLRequest(const TQString &)),
@@ -1107,7 +1107,7 @@ void konsolePart::newSession()
// se->run();
connect( se, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( sessionDestroyed() ) );
// setFont( n_font ); // we do this here, to make TEWidget recalculate
- // its geometry..
+ // its tqgeometry..
}
void konsolePart::showShellInDir( const TQString& dir )
@@ -1125,7 +1125,7 @@ void konsolePart::showShellInDir( const TQString& dir )
{
TQString text = dir;
KRun::shellQuote(text);
- text = TQString::fromLatin1("cd ") + text + '\n';
+ text = TQString::tqfromLatin1("cd ") + text + '\n';
te->emitText( text );
};
}
diff --git a/konsole/konsole/konsole_part.h b/konsole/konsole/konsole_part.h
index 1f65106ad..db7533178 100644
--- a/konsole/konsole/konsole_part.h
+++ b/konsole/konsole/konsole_part.h
@@ -52,7 +52,7 @@ public:
konsoleFactory();
virtual ~konsoleFactory();
- virtual KParts::Part* createPartObject(TQWidget *parentWidget = 0, const char *widgetName = 0,
+ virtual KParts::Part* createPartObject(TQWidget *tqparentWidget = 0, const char *widgetName = 0,
TQObject* parent = 0, const char* name = 0,
const char* classname = "KParts::Part",
const TQStringList &args = TQStringList());
@@ -70,7 +70,7 @@ class konsolePart: public KParts::ReadOnlyPart, public TerminalInterface, public
{
Q_OBJECT
public:
- konsolePart(TQWidget *parentWidget, const char *widgetName, TQObject * parent, const char *name, const char *classname = 0);
+ konsolePart(TQWidget *tqparentWidget, const char *widgetName, TQObject * parent, const char *name, const char *classname = 0);
virtual ~konsolePart();
signals:
@@ -140,7 +140,7 @@ signals:
bool doWriteStream( const TQByteArray& );
bool doCloseStream();
- TQWidget* parentWidget;
+ TQWidget* tqparentWidget;
TEWidget* te;
TESession* se;
ColorSchemaList* colors;
diff --git a/konsole/konsole/konsole_wcwidth.h b/konsole/konsole/konsole_wcwidth.h
index b070beb02..a7ca9ad4f 100644
--- a/konsole/konsole/konsole_wcwidth.h
+++ b/konsole/konsole/konsole_wcwidth.h
@@ -9,8 +9,8 @@
#include <tqglobal.h>
#include <tqstring.h>
-int konsole_wcwidth(Q_UINT16 ucs);
-//int konsole_wcwidth_cjk(Q_UINT16 ucs);
+int konsole_wcwidth(TQ_UINT16 ucs);
+//int konsole_wcwidth_cjk(TQ_UINT16 ucs);
int string_width( const TQString &txt );
diff --git a/konsole/konsole/konsolebookmarkmenu.cpp b/konsole/konsole/konsolebookmarkmenu.cpp
index 0686cfbf1..25a71d4e9 100644
--- a/konsole/konsole/konsolebookmarkmenu.cpp
+++ b/konsole/konsole/konsolebookmarkmenu.cpp
@@ -90,14 +90,14 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
addNewFolder();
}
- KBookmarkGroup parentBookmark = m_pManager->findByAddress( m_parentAddress ).toGroup();
+ KBookmarkGroup parentBookmark = m_pManager->tqfindByAddress( m_parentAddress ).toGroup();
Q_ASSERT(!parentBookmark.isNull());
bool separatorInserted = false;
for ( KBookmark bm = parentBookmark.first(); !bm.isNull();
bm = parentBookmark.next(bm) )
{
TQString text = bm.text();
- text.replace( '&', "&&" );
+ text.tqreplace( '&', "&&" );
if ( !separatorInserted && m_bIsRoot) { // inserted before the first konq bookmark, to avoid the separator if no konq bookmark
m_parentMenu->insertSeparator();
separatorInserted = true;
diff --git a/konsole/konsole/linefont.h b/konsole/konsole/linefont.h
index 9873c43d4..a68457023 100644
--- a/konsole/konsole/linefont.h
+++ b/konsole/konsole/linefont.h
@@ -1,7 +1,7 @@
// WARNING: Autogenerated by "fontembedder ./linefont.src".
// You probably do not want to hand-edit this!
-static const Q_UINT32 LineChars[] = {
+static const TQ_UINT32 LineChars[] = {
0x00007c00, 0x000fffe0, 0x00421084, 0x00e739ce, 0x00000000, 0x00000000, 0x00000000, 0x00000000,
0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00427000, 0x004e7380, 0x00e77800, 0x00ef7bc0,
0x00421c00, 0x00439ce0, 0x00e73c00, 0x00e7bde0, 0x00007084, 0x000e7384, 0x000079ce, 0x000f7bce,
diff --git a/konsole/konsole/main.cpp b/konsole/konsole/main.cpp
index 7be5e5146..a14372ce2 100644
--- a/konsole/konsole/main.cpp
+++ b/konsole/konsole/main.cpp
@@ -324,7 +324,7 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
TQString term = "";
if(args->isSet("tn")) {
- term=TQString::fromLatin1(args->getOption("tn"));
+ term=TQString::tqfromLatin1(args->getOption("tn"));
}
login_shell = args->isSet("ls");
@@ -644,13 +644,13 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
//// Temporary code, waiting for Qt to do this properly
// Delete all toplevel widgets that have WDestructiveClose
- TQWidgetList *list = TQApplication::topLevelWidgets();
+ TQWidgetList *list = TQApplication::tqtopLevelWidgets();
// remove all toplevel widgets that have a parent (i.e. they
// got WTopLevel explicitly), they'll be deleted by the parent
list->first();
while( list->current())
{
- if( list->current()->parentWidget() != NULL || !list->current()->testWFlags( Qt::WDestructiveClose ) )
+ if( list->current()->tqparentWidget() != NULL || !list->current()->testWFlags( Qt::WDestructiveClose ) )
{
list->remove();
continue;
diff --git a/konsole/konsole/schema.cpp b/konsole/konsole/schema.cpp
index 8d85329eb..825d13efe 100644
--- a/konsole/konsole/schema.cpp
+++ b/konsole/konsole/schema.cpp
@@ -101,7 +101,7 @@ static const char *colornames[TABLE_COLORS] =
static const ColorEntry default_table[TABLE_COLORS] =
// The following are almost IBM standard color codes, with some slight
// gamma correction for the dim colors to compensate for bright X screens.
- // It contains the 8 ansiterm/xterm colors in 2 intensities.
+ // It tqcontains the 8 ansiterm/xterm colors in 2 intensities.
{
ColorEntry( TQColor(0x00,0x00,0x00), 0, 0 ), ColorEntry(
TQColor(0xFF,0xFF,0xFF), 1, 0 ), // Dfore, Dback
@@ -131,7 +131,7 @@ ColorSchema::ColorSchema(const TQString& pathname)
,lastRead(new TQDateTime())
{
//start with a valid time, aleXXX
- *lastRead = TQDateTime::currentDateTime();
+ *lastRead = TQDateTime::tqcurrentDateTime();
TQString fPath = pathname.startsWith("/") ? pathname : locate("data", "konsole/"+pathname);
if (fPath.isEmpty() || !TQFile::exists(fPath))
{
@@ -169,7 +169,7 @@ ColorSchema::ColorSchema(KConfig& c)
m_title = c.readEntry("Title",i18n("[no title]"));
m_imagePath = c.readEntry("ImagePath");
- m_alignment = c.readNumEntry("ImageAlignment",1);
+ m_tqalignment = c.readNumEntry("ImageAlignment",1);
m_useTransparency = c.readBoolEntry("UseTransparency",false);
m_tr_r = c.readNumEntry("TransparentR",0);
@@ -203,7 +203,7 @@ void ColorSchema::clearSchema()
}
m_title = i18n("[no title]");
m_imagePath = "";
- m_alignment = 1;
+ m_tqalignment = 1;
m_useTransparency = false;
m_tr_x = 0.0;
m_tr_r = 0;
@@ -216,7 +216,7 @@ void ColorSchema::setDefaultSchema()
m_numb = 0;
m_title = i18n("Konsole Default");
m_imagePath = ""; // background pixmap
- m_alignment = 1; // none
+ m_tqalignment = 1; // none
m_useTransparency = false; // not use pseudo-transparency by default
m_tr_r = m_tr_g = m_tr_b = 0; // just to be on the safe side
m_tr_x = 0.0;
@@ -273,7 +273,7 @@ void ColorSchema::writeConfig(const TQString& path) const
c.setGroup("SchemaGeneral");
c.writeEntry("Title",m_title);
c.writeEntry("ImagePath",m_imagePath);
- c.writeEntry("ImageAlignment",m_alignment);
+ c.writeEntry("ImageAlignment",m_tqalignment);
c.writeEntry("UseTransparency",m_useTransparency);
c.writeEntry("TransparentR",m_tr_r);
@@ -313,7 +313,7 @@ bool ColorSchema::rereadSchemaFile()
char line[100];
- *lastRead = TQDateTime::currentDateTime();
+ *lastRead = TQDateTime::tqcurrentDateTime();
while (fscanf(sysin,"%80[^\n]\n",line) > 0)
{
@@ -334,7 +334,7 @@ bool ColorSchema::rereadSchemaFile()
TQString qline(line);
m_imagePath = locate("wallpaper", qline.mid( qline.find(" ",7)+1 ) );
- m_alignment = attr;
+ m_tqalignment = attr;
}
if (!strncmp(line,"transparency",12))
{ float rx;
@@ -615,7 +615,7 @@ bool ColorSchemaList::checkSchemas()
// now.
//
//
- TQDateTime now = TQDateTime::currentDateTime();
+ TQDateTime now = TQDateTime::tqcurrentDateTime();
r = updateAllSchemaTimes(now);
diff --git a/konsole/konsole/schema.h b/konsole/konsole/schema.h
index 904767df6..42cdfe1ed 100644
--- a/konsole/konsole/schema.h
+++ b/konsole/konsole/schema.h
@@ -150,7 +150,7 @@ protected:
int numb() {if (!m_fileRead) rereadSchemaFile();return m_numb;};
const TQString& title() {if (!m_fileRead) rereadSchemaFile();return m_title;};
const TQString& imagePath() {if (!m_fileRead) rereadSchemaFile();return m_imagePath;};
- int alignment() {if (!m_fileRead) rereadSchemaFile();return m_alignment;};
+ int tqalignment() {if (!m_fileRead) rereadSchemaFile();return m_tqalignment;};
const ColorEntry* table() {if (!m_fileRead) rereadSchemaFile();return m_table;};
bool useTransparency() {if (!m_fileRead) rereadSchemaFile();return m_useTransparency;};
double tr_x() {if (!m_fileRead) rereadSchemaFile();return m_tr_x;};
@@ -162,7 +162,7 @@ protected:
private:
int m_numb;
int m_tr_r, m_tr_g, m_tr_b;
- int m_alignment;
+ int m_tqalignment;
TQString m_title;
TQString m_imagePath;
ColorEntry m_table[TABLE_COLORS];
@@ -234,7 +234,7 @@ private:
/**
* This isn't really used, but it could be. A newly
- * constructed ColorSchemaList contains one element:
+ * constructed ColorSchemaList tqcontains one element:
* the defaultSchema, with serial number 0.
*/
ColorSchema *defaultSchema;
diff --git a/konsole/konsole/session.cpp b/konsole/konsole/session.cpp
index 53990af2f..a4d8ff4f5 100644
--- a/konsole/konsole/session.cpp
+++ b/konsole/konsole/session.cpp
@@ -133,11 +133,11 @@ void TESession::ptyError()
{
// FIXME: sh->error() is always empty
if ( sh->error().isEmpty() )
- KMessageBox::error( te->topLevelWidget(),
+ KMessageBox::error( te->tqtopLevelWidget(),
i18n("Konsole is unable to open a PTY (pseudo teletype). It is likely that this is due to an incorrect configuration of the PTY devices. Konsole needs to have read/write access to the PTY devices."),
i18n("A Fatal Error Has Occurred") );
else
- KMessageBox::error(te->topLevelWidget(), sh->error());
+ KMessageBox::error(te->tqtopLevelWidget(), sh->error());
emit done(this);
}
@@ -232,7 +232,7 @@ void TESession::setUserTitle( int what, const TQString &caption )
renameSession(caption);
if (what == 31) {
cwd=caption;
- cwd=cwd.replace( TQRegExp("^~"), TQDir::homeDirPath() );
+ cwd=cwd.tqreplace( TQRegExp("^~"), TQDir::homeDirPath() );
emit openURLRequest(cwd);
}
if (what == 32) { // change icon via \033]32;Icon\007
@@ -637,7 +637,7 @@ void TESession::startZModem(const TQString &zmodem, const TQString &dir, const T
connect(zmodemProc,TQT_SIGNAL (receivedStdout (KProcess *, char *, int)),
this, TQT_SLOT(zmodemSendBlock(KProcess *, char *, int)));
connect(zmodemProc,TQT_SIGNAL (receivedStderr (KProcess *, char *, int)),
- this, TQT_SLOT(zmodemStatus(KProcess *, char *, int)));
+ this, TQT_SLOT(zmodemtqStatus(KProcess *, char *, int)));
connect(zmodemProc,TQT_SIGNAL (processExited(KProcess *)),
this, TQT_SLOT(zmodemDone()));
@@ -645,7 +645,7 @@ void TESession::startZModem(const TQString &zmodem, const TQString &dir, const T
connect( sh,TQT_SIGNAL(block_in(const char*,int)), this, TQT_SLOT(zmodemRcvBlock(const char*,int)) );
connect( sh,TQT_SIGNAL(buffer_empty()), this, TQT_SLOT(zmodemContinue()));
- zmodemProgress = new ZModemDialog(te->topLevelWidget(), false,
+ zmodemProgress = new ZModemDialog(te->tqtopLevelWidget(), false,
i18n("ZModem Progress"));
connect(zmodemProgress, TQT_SIGNAL(user1Clicked()),
@@ -671,7 +671,7 @@ void TESession::zmodemContinue()
// qWarning("ZModem resume");
}
-void TESession::zmodemStatus(KProcess *, char *data, int len)
+void TESession::zmodemtqStatus(KProcess *, char *data, int len)
{
TQCString msg(data, len+1);
while(!msg.isEmpty())
@@ -767,7 +767,7 @@ QCStringList TESession::functionsDynamic()
void TESession::onRcvBlock( const char* buf, int len )
{
em->onRcvBlock( buf, len );
- emit receivedData( TQString::fromLatin1( buf, len ) );
+ emit receivedData( TQString::tqfromLatin1( buf, len ) );
}
void TESession::print( TQPainter &paint, bool friendly, bool exact )
diff --git a/konsole/konsole/session.h b/konsole/konsole/session.h
index cbe41ab50..69be6cb86 100644
--- a/konsole/konsole/session.h
+++ b/konsole/konsole/session.h
@@ -137,7 +137,7 @@ public slots:
void slotZModemDetected();
void emitZModemDetected();
- void zmodemStatus(KProcess *, char *data, int len);
+ void zmodemtqStatus(KProcess *, char *data, int len);
void zmodemSendBlock(KProcess *, char *data, int len);
void zmodemRcvBlock(const char *data, int len);
void zmodemDone();
diff --git a/konsole/konsole/TEWidget.cpp b/konsole/konsole/TEWidget.cpp
index cb16ff497..91087d9c0 100644
--- a/konsole/konsole/TEWidget.cpp
+++ b/konsole/konsole/TEWidget.cpp
@@ -116,7 +116,7 @@ bool TEWidget::s_standalone = false;
static const ColorEntry base_color_table[TABLE_COLORS] =
// The following are almost IBM standard color codes, with some slight
// gamma correction for the dim colors to compensate for bright X screens.
// It contains the 8 ansiterm/xterm colors in 2 intensities.
{
// Fixme: could add faint colors here, also.
// normal
@@ -144,7 +144,7 @@ static const ColorEntry base_color_table[TABLE_COLORS] =
void TEWidget::setDefaultBackColor(const TQColor& color)
{
defaultBgColor = color;
- if (qAlpha(blend_color) != 0xff && !backgroundPixmap())
+ if (tqAlpha(blend_color) != 0xff && !backgroundPixmap())
setBackgroundColor(getDefaultBackColor());
}
@@ -165,14 +165,14 @@ void TEWidget::setColorTable(const ColorEntry table[])
for (int i = 0; i < TABLE_COLORS; i++) color_table[i] = table[i];
const TQPixmap* pm = backgroundPixmap();
if (!pm)
- if (!argb_visual || (qAlpha(blend_color) == 0xff))
+ if (!argb_visual || (tqAlpha(blend_color) == 0xff))
setBackgroundColor(getDefaultBackColor());
else {
- float alpha = qAlpha(blend_color) / 255.;
- int pixel = qAlpha(blend_color) << 24 |
- int(qRed(blend_color) * alpha) << 16 |
- int(qGreen(blend_color) * alpha) << 8 |
- int(qBlue(blend_color) * alpha);
+ float alpha = tqAlpha(blend_color) / 255.;
+ int pixel = tqAlpha(blend_color) << 24 |
+ int(tqRed(blend_color) * alpha) << 16 |
+ int(tqGreen(blend_color) * alpha) << 8 |
+ int(tqBlue(blend_color) * alpha);
setBackgroundColor(TQColor(blend_color, pixel));
}
update();
@@ -191,14 +191,14 @@ void TEWidget::setColorTable(const ColorEntry table[])
xterm fonts have these at 0x00..0x1f.
QT's iso mapping leaves 0x00..0x7f without any changes. But the graphicals
- come in here as proper unicode characters.
+ come in here as proper tqunicode characters.
We treat non-iso10646 fonts as VT100 extended and do the requiered mapping
- from unicode to 0x00..0x1f. The remaining translation is then left to the
+ from tqunicode to 0x00..0x1f. The remaining translation is then left to the
QCodec.
*/
-static inline bool isLineChar(Q_UINT16 c) { return ((c & 0xFF80) == 0x2500);}
+static inline bool isLineChar(TQ_UINT16 c) { return ((c & 0xFF80) == 0x2500);}
// assert for i in [0..31] : vt100extended(vt100_graphics[i]) == i.
@@ -213,7 +213,7 @@ unsigned short vt100_graphics[32] =
/*
static TQChar vt100extended(TQChar c)
{
- switch (c.unicode())
+ switch (c.tqunicode())
{
case 0x25c6 : return 1;
case 0x2592 : return 2;
@@ -265,7 +265,7 @@ void TEWidget::fontChange(const TQFont &)
// "Base character width on widest ASCII character. This prevents too wide
// characters in the presence of double wide (e.g. Japanese) characters."
// Get the width from representative normal width characters
- font_w = qRound((double)fm.width(REPCHAR)/(double)strlen(REPCHAR));
+ font_w = tqRound((double)fm.width(REPCHAR)/(double)strlen(REPCHAR));
fixed_font = true;
int fw = fm.width(REPCHAR[0]);
@@ -382,7 +382,7 @@ TEWidget::TEWidget(TQWidget *parent, const char *name)
,m_cursorCol(0)
,m_isIMEdit(false)
,m_isIMSel(false)
-,blend_color(qRgba(0,0,0,0xff))
+,blend_color(tqRgba(0,0,0,0xff))
{
// The offsets are not yet calculated.
// Do not calculate these too often to be more smoothly when resizing
@@ -405,7 +405,7 @@ TEWidget::TEWidget(TQWidget *parent, const char *name)
setMouseMarks(true);
setColorTable(base_color_table); // init color table
- qApp->installEventFilter( this ); //FIXME: see below
+ tqApp->installEventFilter( this ); //FIXME: see below
KCursor::setAutoHideCursor( this, true );
// Init DnD ////////////////////////////////////////////////////////////////
@@ -428,7 +428,7 @@ TEWidget::TEWidget(TQWidget *parent, const char *name)
// Here's a start (David)
TEWidget::~TEWidget()
{
- qApp->removeEventFilter( this );
+ tqApp->removeEventFilter( this );
if (image) free(image);
}
@@ -439,7 +439,7 @@ TEWidget::~TEWidget()
/* ------------------------------------------------------------------------- */
/**
- A table for emulating the simple (single width) unicode drawing chars.
+ A table for emulating the simple (single width) tqunicode drawing chars.
It represents the 250x - 257x glyphs. If it's zero, we can't use it.
if it's not, it's encoded as follows: imagine a 5x5 grid where the points are numbered
0 to 24 left to top, top to bottom. Each point is represented by the corresponding bit.
@@ -496,7 +496,7 @@ static void drawLineChar(TQPainter& paint, int x, int y, int w, int h, uchar cod
int ex = x + w - 1;
int ey = y + h - 1;
- Q_UINT32 toDraw = LineChars[code];
+ TQ_UINT32 toDraw = LineChars[code];
//Top lines:
if (toDraw & TopL)
@@ -576,7 +576,7 @@ void TEWidget::drawTextFixed(TQPainter &paint, int x, int y,
}
//Check for line-drawing char
- if (isLineChar(drawstr[0].unicode()))
+ if (isLineChar(drawstr[0].tqunicode()))
{
uchar code = drawstr[0].cell();
if (LineChars[code])
@@ -624,17 +624,17 @@ void TEWidget::drawAttrStr(TQPainter &paint, TQRect rect,
attr->b == cacol(CO_DFT, colorsSwapped ? DEFAULT_FORE_COLOR : DEFAULT_BACK_COLOR) )
// draw background colors with 75% opacity
- if ( argb_visual && qAlpha(blend_color) < 0xff ) {
+ if ( argb_visual && tqAlpha(blend_color) < 0xff ) {
QRgb col = bColor.rgb();
- Q_UINT8 salpha = 192;
- Q_UINT8 dalpha = 255 - salpha;
+ TQ_UINT8 salpha = 192;
+ TQ_UINT8 dalpha = 255 - salpha;
int a, r, g, b;
- a = QMIN( (qAlpha (col) * salpha) / 255 + (qAlpha (blend_color) * dalpha) / 255, 255 );
- r = QMIN( (qRed (col) * salpha) / 255 + (qRed (blend_color) * dalpha) / 255, 255 );
- g = QMIN( (qGreen (col) * salpha) / 255 + (qGreen (blend_color) * dalpha) / 255, 255 );
- b = QMIN( (qBlue (col) * salpha) / 255 + (qBlue (blend_color) * dalpha) / 255, 255 );
+ a = QMIN( (tqAlpha (col) * salpha) / 255 + (tqAlpha (blend_color) * dalpha) / 255, 255 );
+ r = QMIN( (tqRed (col) * salpha) / 255 + (tqRed (blend_color) * dalpha) / 255, 255 );
+ g = QMIN( (tqGreen (col) * salpha) / 255 + (tqGreen (blend_color) * dalpha) / 255, 255 );
+ b = QMIN( (tqBlue (col) * salpha) / 255 + (tqBlue (blend_color) * dalpha) / 255, 255 );
col = a << 24 | r << 16 | g << 8 | b;
int pixel = a << 24 | (r * a / 255) << 16 | (g * a / 255) << 8 | (b * a / 255);
@@ -695,8 +695,8 @@ void TEWidget::drawAttrStr(TQPainter &paint, TQRect rect,
{
// ### Disabled for now, since it causes problems with characters
// that use the full width and/or height of the character cells.
- //bool shadow = ( !isPrinting && qAlpha(blend_color) < 0xff
- // && qGray( fColor.rgb() ) > 64 );
+ //bool shadow = ( !isPrinting && tqAlpha(blend_color) < 0xff
+ // && tqGray( fColor.rgb() ) > 64 );
bool shadow = false;
paint.setPen(fColor);
int x = rect.x();
@@ -830,7 +830,7 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
const ca* lcl = &image[y*this->columns];
const ca* const ext = &newimg[y*columns];
- // The dirty mask indicates which characters need repainting. We also
+ // The dirty tqmask indicates which characters need tqrepainting. We also
// mark surrounding neighbours dirty, in case the character exceeds
// its cell boundaries
memset(dirtyMask, 0, cols+2);
@@ -856,7 +856,7 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
// where characters exceed their cell width.
if (dirtyMask[x])
{
- Q_UINT16 c = ext[x+0].c;
+ TQ_UINT16 c = ext[x+0].c;
if ( !c )
continue;
int p = 0;
@@ -947,7 +947,7 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
mResizeLabel = new TQLabel(i18n("Size: XXX x XXX"), mResizeWidget);
l->addWidget(mResizeLabel, 1, AlignCenter);
mResizeWidget->setMinimumWidth(mResizeLabel->fontMetrics().width(i18n("Size: XXX x XXX"))+20);
- mResizeWidget->setMinimumHeight(mResizeLabel->sizeHint().height()+20);
+ mResizeWidget->setMinimumHeight(mResizeLabel->tqsizeHint().height()+20);
mResizeTimer = new TQTimer(this);
connect(mResizeTimer, TQT_SIGNAL(timeout()), mResizeWidget, TQT_SLOT(hide()));
}
@@ -1097,7 +1097,7 @@ void TEWidget::paintContents(TQPainter &paint, const TQRect &rect, bool pm)
TQChar *disstrU = new QChar[columns];
for (int y = luy; y <= rly; y++)
{
- Q_UINT16 c = image[loc(lux,y)].c;
+ TQ_UINT16 c = image[loc(lux,y)].c;
int x = lux;
if(!c && x)
x--; // Search for start of multi-col char
@@ -1152,14 +1152,14 @@ void TEWidget::blinkEvent()
{
blinking = !blinking;
isBlinkEvent = true;
- repaint(false);
+ tqrepaint(false);
isBlinkEvent = false;
}
void TEWidget::blinkCursorEvent()
{
cursorBlinking = !cursorBlinking;
- repaint(cursorRect, true);
+ tqrepaint(cursorRect, true);
}
/* ------------------------------------------------------------------------- */
@@ -1178,9 +1178,9 @@ void TEWidget::propagateSize()
if (isFixedSize)
{
setSize(columns, lines);
- TQFrame::setFixedSize(sizeHint());
- parentWidget()->adjustSize();
- parentWidget()->setFixedSize(parentWidget()->sizeHint());
+ TQFrame::setFixedSize(tqsizeHint());
+ tqparentWidget()->adjustSize();
+ tqparentWidget()->setFixedSize(tqparentWidget()->tqsizeHint());
return;
}
if (image)
@@ -1288,7 +1288,7 @@ void TEWidget::mousePressEvent(TQMouseEvent* ev)
return;
}
- if ( !contentsRect().contains(ev->pos()) ) return;
+ if ( !contentsRect().tqcontains(ev->pos()) ) return;
TQPoint tL = contentsRect().topLeft();
int tLx = tL.x();
int tLy = tL.y();
@@ -1371,7 +1371,7 @@ void TEWidget::mouseMoveEvent(TQMouseEvent* ev)
return;
} else if (dragInfo.state == diDragging) {
// this isn't technically needed because mouseMoveEvent is suppressed during
- // Qt drag operations, replaced by dragMoveEvent
+ // Qt drag operations, tqreplaced by dragMoveEvent
return;
}
@@ -1390,7 +1390,7 @@ void TEWidget::setSelectionEnd()
void TEWidget::extendSelection( TQPoint pos )
{
- //if ( !contentsRect().contains(ev->pos()) ) return;
+ //if ( !contentsRect().tqcontains(ev->pos()) ) return;
TQPoint tL = contentsRect().topLeft();
int tLx = tL.x();
int tLy = tL.y();
@@ -1735,14 +1735,14 @@ void TEWidget::mouseTripleClickEvent(TQMouseEvent* ev)
void TEWidget::focusInEvent( TQFocusEvent * )
{
- repaint(cursorRect, true); // *do* erase area, to get rid of the
+ tqrepaint(cursorRect, true); // *do* erase area, to get rid of the
// hollow cursor rectangle.
}
void TEWidget::focusOutEvent( TQFocusEvent * )
{
- repaint(cursorRect, true); // don't erase area
+ tqrepaint(cursorRect, true); // don't erase area
}
bool TEWidget::focusNextPrevChild( bool next )
@@ -1759,7 +1759,7 @@ int TEWidget::charClass(UINT16 ch) const
TQChar qch=TQChar(ch);
if ( qch.isSpace() ) return ' ';
- if ( qch.isLetterOrNumber() || word_characters.contains(qch, false) )
+ if ( qch.isLetterOrNumber() || word_characters.tqcontains(qch, false) )
return 'a';
// Everything else is weird
@@ -1802,7 +1802,7 @@ void TEWidget::emitSelection(bool useXselection,bool appendReturn)
text.append("\r");
if ( ! text.isEmpty() )
{
- text.replace("\n", "\r");
+ text.tqreplace("\n", "\r");
TQKeyEvent e(TQEvent::KeyPress, 0,-1,0, text);
emit keyPressedSignal(&e); // expose as a big fat keypress event
emit clearSelectionSignal();
@@ -1853,7 +1853,7 @@ void TEWidget::onClearSelection()
//FIXME: an `eventFilter' has been installed instead of a `keyPressEvent'
// due to a bug in `QT' or the ignorance of the author to prevent
// repaint events being emitted to the screen whenever one leaves
// or reenters the screen to/from another application.
//
// Troll says one needs to change focusInEvent() and focusOutEvent(),
@@ -1873,7 +1873,7 @@ void TEWidget::doScroll(int lines)
bool TEWidget::eventFilter( TQObject *obj, TQEvent *e )
{
if ( (e->type() == TQEvent::Accel ||
- e->type() == TQEvent::AccelAvailable ) && qApp->focusWidget() == this )
+ e->type() == TQEvent::AccelAvailable ) && tqApp->tqfocusWidget() == this )
{
static_cast<TQKeyEvent *>( e )->ignore();
return false;
@@ -1971,13 +1971,13 @@ void TEWidget::imEndEvent( TQIMEvent *e )
int tLx = tL.x();
int tLy = tL.y();
- TQRect repaintRect = TQRect( bX+tLx, bY+tLy+font_h*m_imStartLine,
+ TQRect tqrepaintRect = TQRect( bX+tLx, bY+tLy+font_h*m_imStartLine,
contentsRect().width(), contentsRect().height() );
m_imStart = 0;
m_imPreeditLength = 0;
m_isIMEdit = m_isIMSel = false;
- repaint( repaintRect, true );
+ tqrepaint( tqrepaintRect, true );
}
// Override any Ctrl+<key> accelerator when pressed with the keyboard
@@ -2097,7 +2097,7 @@ void TEWidget::clearImage()
void TEWidget::calcGeometry()
{
- scrollbar->resize(TQApplication::style().pixelMetric(TQStyle::PM_ScrollBarExtent),
+ scrollbar->resize(TQApplication::style().tqpixelMetric(TQStyle::PM_ScrollBarExtent),
contentsRect().height());
switch(scrollLoc)
{
@@ -2170,7 +2170,7 @@ void TEWidget::setFixedSize(int cols, int lins)
TQFrame::setFixedSize(m_size);
}
-TQSize TEWidget::sizeHint() const
+TQSize TEWidget::tqsizeHint() const
{
return m_size;
}
@@ -2235,7 +2235,7 @@ void TEWidget::dropEvent(TQDropEvent* event)
TQString tmp;
if (url.isLocalFile()) {
tmp = url.path(); // local URL : remove protocol. This helps "ln" & "cd" and doesn't harm the others
- } else if ( url.protocol() == TQString::fromLatin1( "mailto" ) ) {
+ } else if ( url.protocol() == TQString::tqfromLatin1( "mailto" ) ) {
justPaste = true;
break;
} else {
@@ -116,7 +116,7 @@ bool TEWidget::s_standalone = false;
// The following are almost IBM standard color codes, with some slight
// gamma correction for the dim colors to compensate for bright X screens.
-// It contains the 8 ansiterm/xterm colors in 2 intensities.
+// It tqcontains the 8 ansiterm/xterm colors in 2 intensities.
{
// Fixme: could add faint colors here, also.
@@ -1853,7 +1853,7 @@ void TEWidget::onClearSelection()
//FIXME: an `eventFilter' has been installed instead of a `keyPressEvent'
// due to a bug in `QT' or the ignorance of the author to prevent
-// repaint events being emitted to the screen whenever one leaves
+// tqrepaint events being emitted to the screen whenever one leaves
// or reenters the screen to/from another application.
//
diff --git a/konsole/konsole/TEmulation.cpp b/konsole/konsole/TEmulation.cpp
index 39aeab542..f8e3e501d 100644
--- a/konsole/konsole/TEmulation.cpp
+++ b/konsole/konsole/TEmulation.cpp
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
// process application unicode input to terminal
// this is a trivial scanner
{
c &= 0xff;
@@ -284,7 +284,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
scr->setHistCursor(scr->getHistLines());
if (!ev->text().isEmpty())
{ // A block of text
// Note that the text is proper unicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.
emit sndBlock(ev->text().ascii(),ev->text().length());
@@ -299,7 +299,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
// Unblocking, Byte to Unicode translation --------------------------------- --
/*
- We are doing code conversion from locale to unicode first.
+ We are doing code conversion from locale to tqunicode first.
*/
void TEmulation::onRcvBlock(const char *s, int len)
@@ -345,7 +345,7 @@ void TEmulation::onRcvBlock(const char *s, int len)
if (r[j].category() == TQChar::Mark_NonSpacing)
scr->compose(r.mid(j,1));
else
- onRcvChar(r[j].unicode());
+ onRcvChar(r[j].tqunicode());
}
i = l;
}
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
-// process application unicode input to terminal
+// process application tqunicode input to terminal
// this is a trivial scanner
{
@@ -284,7 +284,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
if (!ev->text().isEmpty())
{ // A block of text
- // Note that the text is proper unicode.
+ // Note that the text is proper tqunicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.
diff --git a/konsole/konsole/konsole_wcwidth.cpp b/konsole/konsole/konsole_wcwidth.cpp
index 73d7c7131..63abe8dd1 100644
--- a/konsole/konsole/konsole_wcwidth.cpp
+++ b/konsole/konsole/konsole_wcwidth.cpp
@@ -19,7 +19,7 @@ struct interval {
};
/* auxiliary function for binary search in interval table */
-static int bisearch(Q_UINT16 ucs, const struct interval *table, int max) {
+static int bisearch(TQ_UINT16 ucs, const struct interval *table, int max) {
int min = 0;
int mid;
@@ -65,11 +65,11 @@ static int bisearch(Q_UINT16 ucs, const struct interval *table, int max) {
* ISO 8859-1 and WGL4 characters, Unicode control characters,
* etc.) have a column width of 1.
*
* This implementation assumes that Q_UINT16 characters are encoded
* in ISO 10646.
*/
-int konsole_wcwidth_normal(Q_UINT16 ucs)
+int konsole_wcwidth_normal(TQ_UINT16 ucs)
{
/* sorted list of non-overlapping intervals of non-spacing characters */
static const struct interval combining[] = {
@@ -143,7 +143,7 @@ int konsole_wcwidth_normal(Q_UINT16 ucs)
* encodings who want to migrate to UCS. It is not otherwise
* recommended for general use.
*/
-int konsole_wcwidth_cjk(Q_UINT16 ucs)
+int konsole_wcwidth_cjk(TQ_UINT16 ucs)
{
/* sorted list of non-overlapping intervals of East Asian Ambiguous
* characters */
@@ -214,13 +214,13 @@ int string_width( const TQString &txt )
int w = 0;
for ( uint i = 1; i < txt.length(); ++i ) {
- w += konsole_wcwidth(txt[i].unicode());
+ w += konsole_wcwidth(txt[i].tqunicode());
}
return w;
}
-int konsole_wcwidth(Q_UINT16 ucs) {
+int konsole_wcwidth(TQ_UINT16 ucs) {
static int use_wcwidth_cjk = (getenv("KONSOLE_WCWIDTH_CJK")) ? 1: 0;
@@ -65,11 +65,11 @@ static int bisearch(Q_UINT16 ucs, const struct interval *table, int max) {
* etc.) have a column width of 1.
*
- * This implementation assumes that Q_UINT16 characters are encoded
+ * This implementation assumes that TQ_UINT16 characters are encoded
* in ISO 10646.
*/